;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;
;;; schematic/process.sld
;;;
;;; See this project's README for more information.
;;;
;;; Copyright (c) 2014-2016, Evan Hanson <evhan@foldling.org>
;;; See LICENSE for details.
;;;

(define-library (schematic process)
  (import (foldling command-line)
          (foldling command-line getopt-long)
          (scheme base)
          (scheme write)
          (scheme process-context))
  (export command-line-options error-exit version)
  (begin

    ;; The Schematic version, shared across all programs.
    (define version "0.2.0")

    ;; Parses `(command-line)` against the given `spec` and a set of
    ;; common options (currently, `--help` and `--version`).
    (define (command-line-options spec)
      (parse-command-line
       getopt-long
       (cdr (command-line))
       (append spec '(((-h --help))
                      ((-v --version))))))


    ;; Prints an error message for `e` to standard error, then exits
    ;; with an error status.
    (define (error-exit e)
      (let ((message   (error-object-message e))
            (arguments (error-object-irritants e)))
        (when (string? message)
          (parameterize ((current-output-port (current-error-port)))
            (display "Error: ")
            (display message)
            (when (pair? arguments)
              (display ": ")
              (display (car arguments)))
            (newline))
          (exit 1))))))
